var searchData=
[
  ['abs',['ABS',['../da/d8e/lapacke__utils_8h_a996f7be338ccb40d1a2a5abc1ad61759.html#a996f7be338ccb40d1a2a5abc1ad61759',1,'lapacke_utils.h']]],
  ['aladhd',['aladhd',['../d5/d7c/group__aux__lin_ga43c917c7aed0f5b199f88702afcb4801.html#ga43c917c7aed0f5b199f88702afcb4801',1,'aladhd.f']]],
  ['aladhd_2ef',['aladhd.f',['../d7/deb/aladhd_8f.html',1,'']]],
  ['alaerh',['alaerh',['../d5/d7c/group__aux__lin_ga544fc1eb5882794214238ad87cda0b40.html#ga544fc1eb5882794214238ad87cda0b40',1,'alaerh.f']]],
  ['alaerh_2ef',['alaerh.f',['../d5/d21/alaerh_8f.html',1,'']]],
  ['alaesm',['alaesm',['../d5/d7c/group__aux__lin_ga7e95a0425b51195944be2389d11469c9.html#ga7e95a0425b51195944be2389d11469c9',1,'alaesm.f']]],
  ['alaesm_2ef',['alaesm.f',['../d5/df4/alaesm_8f.html',1,'']]],
  ['alahd',['alahd',['../d5/d7c/group__aux__lin_ga20b03b7c76718fe782fcd11607de99ef.html#ga20b03b7c76718fe782fcd11607de99ef',1,'alahd.f']]],
  ['alahd_2ef',['alahd.f',['../dd/d1e/alahd_8f.html',1,'']]],
  ['alahdg',['alahdg',['../d2/df5/group__aux__eig_gad1fc479bdf1b02f3844d630fa505e814.html#gad1fc479bdf1b02f3844d630fa505e814',1,'alahdg.f']]],
  ['alahdg_2ef',['alahdg.f',['../d4/df7/alahdg_8f.html',1,'']]],
  ['alareq',['alareq',['../d2/df5/group__aux__eig_ga0700b15ddc94106ea2d9fe4c97f8cdeb.html#ga0700b15ddc94106ea2d9fe4c97f8cdeb',1,'alareq(PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT):&#160;alareq.f'],['../d5/d7c/group__aux__lin_ga0700b15ddc94106ea2d9fe4c97f8cdeb.html#ga0700b15ddc94106ea2d9fe4c97f8cdeb',1,'alareq(PATH, NMATS, DOTYPE, NTYPES, NIN, NOUT):&#160;alareq.f']]],
  ['alareq_2ef',['alareq.f',['../dc/d25/_e_i_g_2alareq_8f.html',1,'(Global Namespace)'],['../d8/d97/_l_i_n_2alareq_8f.html',1,'(Global Namespace)']]],
  ['alarqg',['alarqg',['../d2/df5/group__aux__eig_ga8879a2d8dc2e86afd6b7e2269b7219ed.html#ga8879a2d8dc2e86afd6b7e2269b7219ed',1,'alarqg.f']]],
  ['alarqg_2ef',['alarqg.f',['../d4/d73/alarqg_8f.html',1,'']]],
  ['alasmg',['alasmg',['../d2/df5/group__aux__eig_ga09ab1f017a25bb3acfed18a650325888.html#ga09ab1f017a25bb3acfed18a650325888',1,'alasmg.f']]],
  ['alasmg_2ef',['alasmg.f',['../d2/d60/alasmg_8f.html',1,'']]],
  ['alasum',['alasum',['../d2/df5/group__aux__eig_gad56ccbe8939c1230b917e03bf7b722b7.html#gad56ccbe8939c1230b917e03bf7b722b7',1,'alasum(TYPE, NOUT, NFAIL, NRUN, NERRS):&#160;alasum.f'],['../d5/d7c/group__aux__lin_gad56ccbe8939c1230b917e03bf7b722b7.html#gad56ccbe8939c1230b917e03bf7b722b7',1,'alasum(TYPE, NOUT, NFAIL, NRUN, NERRS):&#160;alasum.f']]],
  ['alasum_2ef',['alasum.f',['../d2/d4d/_e_i_g_2alasum_8f.html',1,'(Global Namespace)'],['../d7/d0b/_l_i_n_2alasum_8f.html',1,'(Global Namespace)']]],
  ['alasvm',['alasvm',['../d2/df5/group__aux__eig_gad0cdc70e35bb8b07b0e95688e8d2123f.html#gad0cdc70e35bb8b07b0e95688e8d2123f',1,'alasvm(TYPE, NOUT, NFAIL, NRUN, NERRS):&#160;alasvm.f'],['../d5/d7c/group__aux__lin_gad0cdc70e35bb8b07b0e95688e8d2123f.html#gad0cdc70e35bb8b07b0e95688e8d2123f',1,'alasvm(TYPE, NOUT, NFAIL, NRUN, NERRS):&#160;alasvm.f']]],
  ['alasvm_2ef',['alasvm.f',['../d9/dbf/_e_i_g_2alasvm_8f.html',1,'(Global Namespace)'],['../d3/dff/_l_i_n_2alasvm_8f.html',1,'(Global Namespace)']]],
  ['auxiliary_20blas',['Auxiliary BLAS',['../d0/d73/group__aux__blas.html',1,'']]],
  ['aux',['aux',['../d2/df5/group__aux__eig.html',1,'']]],
  ['aux',['aux',['../d5/d7c/group__aux__lin.html',1,'']]],
  ['aux',['aux',['../dc/d83/group__aux__matgen.html',1,'']]],
  ['auxiliary_2ec',['auxiliary.c',['../dd/de1/auxiliary_8c.html',1,'']]],
  ['auxiliary_20routines',['Auxiliary routines',['../d4/d85/group__auxiliary_g_b.html',1,'']]],
  ['auxiliary_20routines',['Auxiliary routines',['../d6/deb/group__auxiliary_g_e.html',1,'']]],
  ['auxiliary_20routines',['Auxiliary routines',['../d5/d13/group__auxiliary_g_t.html',1,'']]],
  ['auxiliary_20routines',['Auxiliary routines',['../de/de7/group__auxiliary_h_e.html',1,'']]],
  ['auxiliary_20routines',['Auxiliary routines',['../d8/d37/group__auxiliary_p_o.html',1,'']]],
  ['auxiliary_20routines',['Auxiliary routines',['../d2/d60/group__auxiliary_p_t.html',1,'']]],
  ['auxiliary_20routines',['Auxiliary routines',['../d9/d5c/group__auxiliary_s_y.html',1,'']]],
  ['auxiliary_20computational_20routines',['auxiliary Computational routines',['../d2/d24/group__aux_o_t_h_e_rcomputational.html',1,'']]]
];
